@@ -1,8 +1,8 @@
+from urllib.parse import urlparse
 import logging
-import os
 
-import jsonschema
 from yaml import load
+import jsonschema
 
 try:
   from yaml import CLoader as Loader, CDumper as Dumper
@@ -18,7 +18,7 @@ CONFIG_SCHEMA = {
     "version": {
       "type": "string",
       "enum": [
-        "installed-packages-diff/2"
+        "installed-packages-diff/3"
       ]
     },
     "groups": {
@@ -58,15 +58,14 @@ CONFIG_SCHEMA = {
         "type": {
           "$ref": "#/definitions/pkg-type"
         },
-        "username": {"type": "string"},
-        "hostname": {"type": "string"},
+        "url": {"type": "string"},
         "excludes": {"type": "array",
                      "items": {
                        "type": "string"
                      }},
       },
       "additionalProperties": False,
-      "required": ["hostname"]
+      "required": ["url"]
     },
     "pkg-type": {
       "id": "#/definitions/pkg-type",
@@ -77,15 +76,10 @@ CONFIG_SCHEMA = {
 }
 
 
-def _expand_value(value):
-  return os.path.expandvars(value) if value else value
-
-
 class Server(object):
   def __init__(self, raw, *, type_from_group=None):
-    self.hostname = _expand_value(raw["hostname"])
-    self.username = _expand_value(raw.get("username", None))
-    self.excludes = {_expand_value(e) for e in raw.get("excludes", [])}
+    self.url = urlparse(raw["url"])
+    self.excludes = {e for e in raw.get("excludes", [])}
     self.type = raw.get("type", type_from_group)
 
 
